@@ -39,7 +39,7 @@ sub Mojo::Webqq::Client::_get_offpic {
         eval{
             my $tmp = File::Temp->new(@opt);
             binmode $tmp;
-            print $tmp $tx->res->content();    
+            print $tmp $tx->res->body();    
             close $tmp;
             open(my $fh,"<:raw",$tmp->filename) or die $!;
             $self->emit(receive_friend_pic => $fh,$tmp->filename,$friend);
